@@ -2,7 +2,7 @@ package Nephia;
 use strict;
 use warnings;
 use File::Spec;
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 use Nephia::Core;
 use Module::Load ();
@@ -17,9 +17,8 @@ sub import {
     my $caller = caller;
     Nephia::Core->export_to_level(1);
 
-    for my $plugin ( Nephia::Core::normalize_plugin_names(@plugins) ) {
-        Nephia::Core::export_plugin_functions($plugin, $caller);
-    }
+    @_ = @plugins;
+    goto do { Nephia::Core->can('nephia_plugins') } if @plugins;
 }
 
 1;
